@@ -1,3 +1,4 @@
+"""All plugging called to check norm for a C file."""
 __all__ = [
     "columns",
     "comma",
@@ -10,8 +11,8 @@ __all__ = [
     "preprocessor",
     "snake_case",
     "solo_space",
-    "stars",
     "statements",
     "trailing_newline",
-    "two_space"
+    "two_space",
+    "operators"
 ]
