@@ -1,6 +1,6 @@
 try:
     from normatrix.source import color
-except:
+except ModuleNotFoundError:
     from normatrix.normatrix.source import color
 
 def print_stats(stats: list, files: list) -> None:
@@ -10,7 +10,8 @@ def print_stats(stats: list, files: list) -> None:
             average_dict[elem[0]] = elem[1]
         else:
             average_dict[elem[0]] += elem[1]
-    average = sum(average_dict.values()) / len(files)
+    if len(files) != 0:
+        average = sum(average_dict.values()) / len(files)
     nb_major = len([elem for elem in stats if elem[2] == 0])
     nb_minor = len([elem for elem in stats if elem[2] == 1])
     nb_info = len([elem for elem in stats if elem[2] == 2])
@@ -21,6 +22,6 @@ def print_stats(stats: list, files: list) -> None:
     color.print_color("green", f"number of INFO: {nb_info}")
     note = -3 * nb_major + -1 * nb_minor
     if note == 0 or note == -0:
-        color.print_color("green", f"note: -0")
+        color.print_color("green", "note: -0")
     else:
         color.print_color("red", f"note : {note}")
